### Signal fitting
#### Fitting function for transients
The function used for fitting Ca2+ release events is shown on Figure \ref{fig:fit}. The shape of the function is described by 4 parameters: amplitude (\(A\)), rise and decay time constants (\(\tau_{r},\tau_{d}\)) and plateau duration (\(d\)). An additional parameter (\(\mu\)) determines the time when the maximum is reached. The function describing a transient is: 
\begin{equation} 
g(A, d, \tau_{d}, \tau_{r}, \mu, t) = A\cdot\left\{
   \begin{array}{l l}
    1-\exp \left(-\frac{t-\mu}{\tau_r} \right)\cdot\exp\left(-2\right) & \quad \mu -2\tau_r\leq t< \mu\\
    1-\exp(-2) & \quad \mu\leq t< \mu+d\\
    \exp\left( -\frac{t-\mu-d}{\tau_d}\right)\cdot\left(1-\exp(-2)\right)& \quad t\geq\mu+d\\
    0 &\quad \mathrm{otherwise}
  \end{array}
  \right.
  \end{equation} 

The transient consists of four phases: zero level before the onset of the transient, an exponential increase with time constant \(\tau_r\) starging when \(t=\mu-2\tau_r\), a plateau phase of duration \(d\) starting at \(t=\mu\) and an exponential decay with time constant \(\tau_d\) starting at \(t=\mu+d\) 

For the optimizer to obtain good performance when fitting, the function used for fitting should be continously differentiable. With this in mind, the transient function is convolved with a gaussian \(G(\sigma)\) to yield the actual fitting function:
\[
f(A, d, \tau_{d}, \tau_{r}, \mu, t, \sigma) = g \ast G
\]
For notational purposes we shall represent the fit function parameters by the vector \[\mathbf{p}=
\left[
\begin{array}{c c c c c}
A&d&\tau_d&\tau_r&\mu
\end{array}
\right]
\]. The smoothing parameter \(\sigma\) will be fixed for all pixels. Therefore, for the *i*-th pixel the *k*-th event is represented by \(f(\mathbf{p}_{i,k},t)\).

The entire raw signal for the *i*-th pixel can be represented as:
\[
F_i(t) =  b(\mathbf{q}_i, t)+ \sum_{k=0}^{m} f(\mathbf{p}_{i,k},t) + W + R
\]
, where \(b\) is a n-th order polynomial with \(\mathbf{q}_i\) being the polynomial coefficients for the *i*-th pixel, summation is performed over all *m* events in the pixel, \(W\) represents noise and \(R\) is the remaining residual not captured in the baseline nor events. Ideally, \(R=0\), but achieving this is limited by the accuracy of the event region detection (we cannot fit what we do not detect) and whether or not our fitting function is general enough to be able to approximate various types of events.

Because it is not known which part of the signal is the event and which is the baseline, the first fit also has to estimate the baseline properties.
Signal in the candidate region is fitted with an extended fit function (Figure \ref{fig:fit}) that also depends on relaxation baseline \(B\) and baseline offset \(C\). The \(C\) parameter allows for the possibility of an elevated background before the release event. 